package cn.com.qmth.examcloud.support.cache;

import cn.com.qmth.examcloud.support.cache.bean.AppCacheBean;
import cn.com.qmth.examcloud.support.cache.bean.BasePaperCacheBean;
import cn.com.qmth.examcloud.support.cache.bean.CourseCacheBean;
import cn.com.qmth.examcloud.support.cache.bean.ExamRecordPropertyCacheBean;
import cn.com.qmth.examcloud.support.cache.bean.OrgExamConfigCacheBean;
import cn.com.qmth.examcloud.support.cache.bean.OrgExamPropertyCacheBean;
import cn.com.qmth.examcloud.support.cache.bean.PrivilegeRolesCacheBean;
import cn.com.qmth.examcloud.support.cache.bean.RootOrgPrivilegesCacheBean;
import cn.com.qmth.examcloud.support.cache.bean.SmsAssemblyCacheBean;
import cn.com.qmth.examcloud.support.cache.bean.SysPropertyCacheBean;
import cn.com.qmth.examcloud.web.cache.ObjectRedisCacheProcessor;

/**
 * 所有缓存对象从此类获取
 *
 * @author WANGWEI
 * @date 2019年5月9日
 * @Copyright (c) 2018-? http://qmth.com.cn All Rights Reserved.
 */
public class CacheHelper {

	/**
	 * 获取APP
	 *
	 * @param appId
	 * @return
	 * @author WANGWEI
	 */
	public static AppCacheBean getApp(Long appId) {
		return ObjectRedisCacheProcessor.get("$_APP:", new Object[]{appId}, AppCacheBean.class);
	}

	/**
	 * 获取系统属性<br>
	 *
	 * @param propKey
	 * @return
	 * @author WANGWEI
	 */
	public static SysPropertyCacheBean getSysProperty(String propKey) {
		return ObjectRedisCacheProcessor.get("$_SYS_PROP:", new Object[]{propKey},
				SysPropertyCacheBean.class, "EC-CORE-BASIC",
				"cn.com.qmth.examcloud.core.basic.service.cache.SystemPropertyCache");
	}

	/**
	 * 根据考试记录id获取考试信息<br>
	 *
	 * @param propKey
	 * @return
	 * @author WANGWEI
	 */
	public static ExamRecordPropertyCacheBean getExamRecordProperty(Long examRecordDataId) {
		return ObjectRedisCacheProcessor.get("OE_EXAM_RECORD_PROP:", new Object[]{examRecordDataId},
				ExamRecordPropertyCacheBean.class, "EC-CORE-OE-STUDENT",
				"cn.com.qmth.examcloud.core.oe.common.cache.ExamRecordPropertyCache");
	}

	/**
	 * 根据短信配置代码获取短信配置详情
	 *
	 * @param smsAssemblyCode
	 *            短信配置代码
	 * @return
	 */
	public static SmsAssemblyCacheBean getSmsAssembly(String smsAssemblyCode) {
		return ObjectRedisCacheProcessor.get("B_SMS_ASSEMBLY_PROP:", new Object[]{smsAssemblyCode},
				SmsAssemblyCacheBean.class, "EC-CORE-BASIC",
				"cn.com.qmth.examcloud.core.basic.service.cache.SmsAssemblyCache");
	}

	/**
	 * 获取权限关联的角色集合
	 *
	 * @param rootOrgId
	 * @param privilegeCode
	 * @return
	 * @author WANGWEI
	 */
	public static PrivilegeRolesCacheBean getPrivilegeRoles(Long rootOrgId, String privilegeCode) {
		return ObjectRedisCacheProcessor.get("$_PRIV_ROLES:",
				new Object[]{rootOrgId, privilegeCode}, PrivilegeRolesCacheBean.class,
				"EC-CORE-BASIC",
				"cn.com.qmth.examcloud.core.basic.service.cache.PrrivilegeRolesCache");
	}

	/**
	 * 获取顶级机构关联的角色集合
	 *
	 * @param rootOrgId
	 * @return
	 * @author WANGWEI
	 */
	public static RootOrgPrivilegesCacheBean getRootOrgPrivileges(Long rootOrgId) {
		return ObjectRedisCacheProcessor.get("B_ROOT_ORG_PRIVS:", new Object[]{rootOrgId},
				PrivilegeRolesCacheBean.class, "EC-CORE-BASIC",
				"cn.com.qmth.examcloud.core.basic.service.cache.RootOrgPrrivilegesCache");
	}

	/**
	 * 获取原始试卷（题库实现）
	 *
	 * @param examId
	 * @param courseCode
	 * @param paperType
	 * @return
	 */
	public static BasePaperCacheBean getBasePaper(Long examId, String courseCode,
			String paperType) {
		return null;
	}

	/**
	 * 查询课程
	 *
	 * @author WANGWEI
	 * @param courseId
	 * @param rootOrgId
	 * @return
	 */
	public static CourseCacheBean getCourse(Long courseId) {
		return ObjectRedisCacheProcessor.get("B_COURSE:", new Object[]{courseId},
				CourseCacheBean.class, "EC-CORE-BASIC",
				"cn.com.qmth.examcloud.core.basic.service.cache.CourseCache");
	}

	/**
	 * 查询机构考试配置
	 *
	 * @author WANGWEI
	 * @param examId
	 * @param orgId
	 * @return
	 */
	public static OrgExamConfigCacheBean getOrgExamConfig(Long examId, Long orgId) {
		return ObjectRedisCacheProcessor.get("E_ORG_EXAM_CONF:", new Object[]{examId, orgId},
				OrgExamConfigCacheBean.class, "EC-CORE-EXAMWORK",
				"cn.com.qmth.examcloud.core.examwork.service.cache.OrgExamConfigCache");
	}

	/**
	 * 查询机构考试属性
	 *
	 * @author WANGWEI
	 * @param examId
	 * @param orgId
	 * @return
	 */
	public static OrgExamPropertyCacheBean getOrgExamProperty(Long examId, Long orgId, String key) {
		return ObjectRedisCacheProcessor.get("E_ORG_EXAM_PROP:", new Object[]{examId, orgId, key},
				OrgExamConfigCacheBean.class, "EC-CORE-EXAMWORK",
				"cn.com.qmth.examcloud.core.examwork.service.cache.OrgExamPropertyCache");
	}

}
